# projecc
A small simple package for projecting orbital elements onto sky plane and vice versa

## Change log

#### Oct 11, 2024:
1.0.1 Fixed coordinate system in KeplerianToCartesian and added Sirius example to notebook

#### Oct 30, 2023:
1.0.0 Initial release
